# API接口列表

以下是一些API接口及其含义的列表：

1.  get\_poc\_list funtion: 获取POC列表
2.  start\_scan funtion: 开始扫描
3.  resume\_scan funtion: 恢复扫描
4.  stop\_scan funtion: 停止扫描
5.  get\_scan\_progress funtion: 获取扫描进度
6.  get\_tasks funtion: 获取任务
7.  get\_statistics data funtion: 获取统计数据
8.  asset\_search funtion: 资产搜索
9.  get\_value\_category funtion: 获取值分类
10. getchildrencategory funtion: 获取子分类
11. get\_ip\_info funtion: 获取IP信息
12. get\_web\_list funtion: 获取Web列表
13. get\_pocs\_funtion: 获取POCS
14. get\_failed\_pocs funtion: 获取失败的POCS
15. get\_vuin\_statistics funtion: 获取漏洞统计信息
16. get\_vulnerability\_search funtion: 获取漏洞搜索结果
17. get\_poc\_info funtion: 获取POC信息
18. get\_ip\_segment funtion: 获取IP段
19. get\_vulanalysis funtion: 获取漏洞分析结果
20. get\_asset\_tags funtion: 获取资产标签
21. get\_env\_info funtion: 获取环境信息
22. set\_envinfo funtion: 设置环境信息

其中，这些API接口包含了一些关于漏洞扫描、统计数据、资产搜索等方面的操作。可以根据实际需求选择相应的API接口进行调用。

更多详情和调用方法访问：http://www.exp-9.com/category-20.html

安装方法：pip install goby-sdk
